"use client";

// src/use-skeleton.ts
import { mapPropsVariants } from "@nextui-org/system";
import { skeleton } from "@nextui-org/theme";
import { useDOMRef } from "@nextui-org/dom-utils";
import { clsx, dataAttr } from "@nextui-org/shared-utils";
import { useMemo } from "react";
function useSkeleton(originalProps) {
  const [props, variantProps] = mapPropsVariants(originalProps, skeleton.variantKeys);
  const { ref, as, children, isLoaded = false, className, classNames, ...otherProps } = props;
  const Component = as || "div";
  const domRef = useDOMRef(ref);
  const slots = useMemo(
    () => skeleton({
      ...variantProps
    }),
    [...Object.values(variantProps), children]
  );
  const baseStyles = clsx(className, classNames == null ? void 0 : classNames.base);
  const getSkeletonProps = (props2 = {}) => {
    return {
      ref: domRef,
      "data-loaded": dataAttr(isLoaded),
      className: slots.base({ class: clsx(baseStyles, props2 == null ? void 0 : props2.className) }),
      ...otherProps
    };
  };
  const getContentProps = (props2 = {}) => {
    return {
      className: slots.content({ class: clsx(classNames == null ? void 0 : classNames.content, props2 == null ? void 0 : props2.className) })
    };
  };
  return { Component, domRef, children, slots, classNames, getSkeletonProps, getContentProps };
}

export {
  useSkeleton
};
