import * as tailwind_variants from 'tailwind-variants';
import * as react from 'react';
import * as _nextui_org_system from '@nextui-org/system';
import { HTMLNextUIProps, PropGetter } from '@nextui-org/system';
import { SkeletonVariantProps, SlotsToClasses, SkeletonSlots } from '@nextui-org/theme';
import { ReactRef } from '@nextui-org/shared-utils';

interface UseSkeletonProps extends HTMLNextUIProps<"div", SkeletonVariantProps> {
    /**
     * Ref to the DOM node.
     */
    ref?: ReactRef<HTMLElement | null>;
    /**
     * The skeleton will be visible while isLoading is `false`.
     * @default false
     */
    isLoaded?: boolean;
    /**
     * Classname or List of classes to change the classNames of the element.
     * if `className` is passed, it will be added to the base slot.
     *
     * @example
     * ```ts
     * <Skeleton classNames={{
     *    base:"base-classes", // skeleton wrapper
     *    content: "content-classes", // children wrapper
     * }} />
     * ```
     */
    classNames?: SlotsToClasses<SkeletonSlots>;
}
declare function useSkeleton(originalProps: UseSkeletonProps): {
    Component: _nextui_org_system.As<any>;
    domRef: react.RefObject<HTMLElement>;
    children: react.ReactNode;
    slots: {
        base: (slotProps?: tailwind_variants.ClassProp<tailwind_variants.ClassValue> | undefined) => string;
        content: (slotProps?: tailwind_variants.ClassProp<tailwind_variants.ClassValue> | undefined) => string;
    };
    classNames: SlotsToClasses<"base" | "content"> | undefined;
    getSkeletonProps: PropGetter<Record<string, unknown>, _nextui_org_system.DOMAttributes<_nextui_org_system.DOMElement>>;
    getContentProps: PropGetter<Record<string, unknown>, _nextui_org_system.DOMAttributes<_nextui_org_system.DOMElement>>;
};
type UseSkeletonReturn = ReturnType<typeof useSkeleton>;

export { UseSkeletonProps, UseSkeletonReturn, useSkeleton };
